pub enum Error {
Cardinality(CardinalityError),
Syntax(SyntaxError),
}Expand description
The error type for this crate.
Variants
Cardinality(CardinalityError)
An error caused by a clause appearing an invalid number of times.
For instance, OBO frames have union_of clauses, that can not appear
only once: they must appear zero, or more than two times. Having a
frame with a single union_of clause will error when attempting to
translate the whole document.
Example:
use fastobo_owl::IntoOwl;
use fastobo_owl::IntoOwlPrefixes;
let mut frame = TermFrame::new(ClassIdent::from(PrefixedIdent::new("TST", "001")));
let id = Box::new(ClassIdent::from(PrefixedIdent::new("TST", "002")));
frame.push(Line::from(TermClause::UnionOf(id)));
let doc = OboDoc::with_entities(vec![EntityFrame::from(frame)]);
let res = doc.into_owl::<SetOntology<String>>();
assert!(matches!(res, Err(fastobo_owl::Error::Cardinality(_))));Syntax(SyntaxError)
An error caused by an element in invalid syntax.
This can be raised while building IRI and Version IRI for an OWL
ontology from an OBO ontology header clause, which may contain
invalid data.